OC.L10N.register(
    "comments",
    {
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>Yorumlar</strong>",
    "%1$s commented" : "%1$s yorumlanmış",
    "%1$s commented on %2$s" : "%1$s yorumlanmış %2$s",
    "Comments" : "Yorumlar",
    "Type in a new comment..." : "Yeni bir yorum yazın",
    "Delete comment" : "Yorumu silin",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "Edit comment" : "Yorumu düzenleyin",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "No other comments available" : "Mevcut başka yorum yok",
    "More comments..." : "Daha fazla yorum...",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "İzin verilen karakterler {count} {max}",
    "{count} unread comments" : "{count} okunmamış yorumlar",
    "Comment" : "Yorum",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>Yorumlar</strong>"
},
"nplurals=2; plural=(n > 1);");
